CON

  _CLKMODE = XTAL1 + PLL16X
  _CLKFREQ = 80_000_000

  _MaxEepromAddress = $7FFF ' = 32,767
  _BufferSize = $200 ' = 512
  _DebugBaud = 57600
  _NumberOfColumns = 16
  
VAR

  word eepromIndex, bufferIndex, groupIndex
  byte buffer[_BufferSize]
  
OBJ

  Eeprom : "Propeller EepromDWD"
  Debug : "fullduplexserial"

PUB Main | localIndex

  Debug.start(31, 30, 0, _DebugBaud)
  waitcnt(clkfreq / 1000 + cnt) ' wait for serial driver cog to start
  
  eepromIndex := 0
  groupIndex := 0
  ' The code below check to see if a key has been pressed 10 times a second.
  ' It displays the message "Press any key to start." every four seconds.
  ' I use it so I don't have to hurry to open the Parallax Serial Terminal.
  ' I also don't have to wait more than a tenth of a second to start the program.
  repeat while debug.rxcheck == -1
    if result++ // 40 == 0 ' result is a temporary variable all methods have.
      Debug.str(String(13, "Press any key to start."))
    waitcnt(clkfreq / 10 + cnt) ' This line waits a tenth of a second
    
    
  Debug.str(String(13, 13, "Beginning of EEPROM dump."))
  Debug.str(String(13, "Values are in hexadecimal.", 13))
  
  repeat
'' -------------- Beginning of heading and formatting stuff ----------------  
    Debug.str(String(13, "Group $"))
    Debug.hex(groupIndex++, 4)
    Debug.str(String(".  Starting at EEPROM location $"))
    Debug.hex(eepromIndex, 4)
    Debug.tx(13)
    Debug.str(String(13, "Base  "))
    repeat _NumberOfColumns
      Debug.str(String(" + ")) 
    Debug.str(String(13, "Addr  "))
    repeat localIndex from 0 to _NumberOfColumns - 1
      Debug.tx(32)
      Debug.hex(localIndex, 2)
    Debug.str(String(13, "______"))
    repeat _NumberOfColumns
      Debug.str(String("___")) 
    Debug.tx(13)  
'' -------------- End of heading and formatting stuff ----------------  
      
    Eeprom.ToRam(@buffer, @buffer + _BufferSize - 1, eepromIndex)
    bufferIndex := 0
    repeat
      Debug.hex(eepromIndex, 4)
      Debug.tx(32) ' a space character 
      Debug.tx("|") 
      repeat _NumberOfColumns
        Debug.tx(32) ' a space character  
        'Debug.tx("$")
        Debug.hex(buffer[bufferIndex++], 2)    
        
      Debug.tx(13)
      eepromIndex += _NumberOfColumns 
    while bufferIndex =< _BufferSize - 1
    Debug.str(String(13, "Press any key to continue."))
    repeat while debug.rxcheck == -1 
  while eepromIndex < _MaxEepromAddress

  Debug.str(String(13, 13, "End of EEPROM dump."))
  Debug.str(String(13, "_MaxEepromAddress = $"))
  Debug.hex(_MaxEepromAddress, 4)
  Debug.str(String(13, "_BufferSize = $"))
  Debug.hex(_BufferSize, 4)
  Debug.str(String(13, "_NumberOfColumns = $"))
  Debug.hex(_NumberOfColumns, 2)

DAT
'' This data is to make the EEPROM dump a little more interesting
'' if F11 (program loaded to EEPROM) is pressed.

testBufferA   byte $AA[$400]
testBufferB   byte $BB[$800]
testBufferC   byte $CC[$200]
testBufferD   byte $DD[$600]
testBufferE   byte $EE[$500]
testBufferF   byte $FF[$700]
  